import 'package:flutter/material.dart';

import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';
import 'package:senior_design_system/senior_design_system.dart';
import 'package:intl/date_symbol_data_local.dart';
import 'package:intl/intl.dart' show DateFormat;

import '../widgets/page_wrapper.dart';

class CalendarExemple extends StatefulWidget {
  const CalendarExemple({Key? key}) : super(key: key);

  @override
  State<CalendarExemple> createState() => _CalendarExempleState();
}

class _CalendarExempleState extends State<CalendarExemple> {
  DateTime _currentDate = DateTime.now();

  @override
  void initState() {
    initializeDateFormatting();
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    final TextEditingController editingController = TextEditingController();
    const String locate = 'pt-BR';
    late DateFormat localeDate;
    localeDate = DateFormat('d/MM/yyyy', locate);

    return PageWrapper(
      title: 'Calendar',
      child: Padding(
        padding: const EdgeInsets.all(SeniorSpacing.normal),
        child: Column(
          children: [
            SeniorTextField(
              controller: editingController,
              label: localeDate.format(_currentDate),
              maxLines: 1,
              leftIcon: FontAwesomeIcons.rocket,
            ),
            SeniorButton(
              label: 'Selecione a data',
              onPressed: () {
                SeniorCalendar(
                  inactiveYesterdays: true,
                  topTextCalendar: 'Selecione a data',
                  selectedDateTime: _currentDate,
                  minSelectedDate: DateTime(DateTime.now().year, 1, 1),
                  maxSelectedDate: DateTime(DateTime.now().year, 12, 31),
                  highlightToday: true,
                  inactiveWeekendAfterToday: false,
                  inactiveWeekendBeforeToday: false,
                  locale: locate,
                  bottomText: 'Selecione uma data no calenário',
                  onDayPressed: (date) {
                    setState(() => _currentDate = date);
                    Navigator.pop(context);
                  },
                ).pickCalendar(context);
              },
            ),
          ],
        ),
      ),
    );
  }
}
